<?php 
/*
 *	                  ....
 *	                .:   '':.
 *	                ::::     ':..
 *	                ::.         ''..
 *	     .:'.. ..':.:::'    . :.   '':.
 *	    :.   ''     ''     '. ::::.. ..:
 *	    ::::.        ..':.. .''':::::  .
 *	    :::::::..    '..::::  :. ::::  :
 *	    ::'':::::::.    ':::.'':.::::  :
 *	    :..   ''::::::....':     ''::  :
 *	    :::::.    ':::::   :     .. '' .
 *	 .''::::::::... ':::.''   ..''  :.''''.
 *	 :..:::'':::::  :::::...:''        :..:
 *	 ::::::. '::::  ::::::::  ..::        .
 *	 ::::::::.::::  ::::::::  :'':.::   .''
 *	 ::: '::::::::.' '':::::  :.' '':  :
 *	 :::   :::::::::..' ::::  ::...'   .
 *	 :::  .::::::::::   ::::  ::::  .:'
 *	  '::'  '':::::::   ::::  : ::  :
 *	            '::::   ::::  :''  .:
 *	             ::::   ::::    ..''
 *	             :::: ..:::: .:''
 *	               ''''  '''''
 *	
 *
 *	AUTOMAD
 *
 *	Copyright (c) 2014 by Marc Anton Dahmen
 *	http://marcdahmen.de
 *
 *	Licensed under the MIT license.
 *	http://automad.org/license
 */


namespace Automad\Core;

defined('AUTOMAD') or die('Direct access not permitted!');

/*
 * 	All ajax requests regarding the site's shared data file get processed here.
 *	Basically that means "Saving" as the first option and "Loading" as the second option.
 *
 *	When "$_POST['data']" exists, that means, that a form with "edited" page information got submitted and the data gets processed to be written into the data file.
 *
 *	NOTE: Only the inner elements of the form are returned. To keep the outer form information lose form the processing here, there must be an outer form existing on the page to wrap that HTML output.	
 */


// Array for returned JSON data.
$output = array();

if (isset($_POST['data'])) {

	// If the posted form contains any "data", save the form's data to the page file.
	$data = array_filter($_POST['data']);

		
	// Build file content to be written to the txt file.
	$pairs = array();

	foreach ($data as $key => $value) {
		$pairs[] = $key . AM_PARSE_PAIR_SEPARATOR . ' ' . $value;
	}

	$content = implode("\r\n\r\n" . AM_PARSE_BLOCK_SEPARATOR . "\r\n\r\n", $pairs);
	

	// Write file.
	$old = umask(0);
	
	if (!@file_put_contents(AM_BASE_DIR .'/automad/gui/special_pages.txt', $content)) {
		$output['error'] = $this->tb['error_permission'] . '<p>' . AM_BASE_DIR .'/automad/gui/special_pages.txt</p>';
	}
	
	umask($old);
	
	
	// Clear the cache.
	$Cache = new Cache();
	$Cache->clear();
	
		
} else {
	
	// Else get the data from the .txt file and return a form's inner HTML containing its information.
	$data = Parse::textFile(AM_BASE_DIR .'/automad/gui/special_pages.txt');
	
	// Array of the standard variable keys, which are always needed.
	$standardKeys = array(special_pages_switcher);
	
	// Collect all keys of all shared site variables, which are found in the template files.
	$themesKeys = array_diff($this->getSiteVarsInThemes(), $standardKeys);
	
	// Start buffering the HTML.
	ob_start();
	
	?>
		<h3><?php echo $this->tb['special_pages_vars_used']; ?></h3> 
		<div class="form-group">
			<label for="input-data-special_pages_switcher"><?php echo $this->tb['special_pages_switcher']; ?></label>
			<textarea id="input-data-special_pages_switcher" class="form-control" name="data[special_pages_switcher]" rows="10" style="height: 50px;"><?php echo str_replace('"', '&quot;', $data['special_pages_switcher']); ?></textarea>
		</div>
		<h3><?php echo $this->tb['special_pages_vars_unused']; ?></h3> 
		<div class="alert alert-info">
			<?php echo $this->tb['special_pages_vars_unused_info'];
			$themes = glob(AM_BASE_DIR . AM_DIR_THEMES . '/*'. $this->siteData[AM_KEY_THEME] . '/*');
			echo '<br/>';
			foreach ($themes as $theme) {
				$themeArray = explode('.', $theme);
				if (end($themeArray) == 'php') {
					echo '<div class="badge">' . basename($theme) . '</div> ';
				}
			}
	
			?>
		</div>
		<div id="automad-custom-variables">
			<?php
			// All unused site-wide variables.
			foreach (array_diff(array_keys($data), $standardKeys, $themesKeys) as $key) {
			echo $this->varTextArea($key, $data[$key], true);
			}	
			?> 
		</div>
		<br />
		<a class="btn btn-default" href="#" data-toggle="modal" data-target="#automad-add-variable-modal"><span class="glyphicon glyphicon-plus"></span> <?php echo $this->tb['special_pages_btn_add']; ?></a>
		
		<hr>
	
		<div class="btn-group btn-group-justified">
			<div class="btn-group"><a class="btn btn-danger" href=""><span class="glyphicon glyphicon-remove"></span> <?php echo $this->tb['btn_discard']; ?></a></div>
			<div class="btn-group"><button type="submit" class="btn btn-success" data-loading-text="<?php echo $this->tb['btn_loading']; ?>"><span class="glyphicon glyphicon-ok"></span> <?php echo $this->tb['btn_save']; ?></button></div>
		</div>
	
		<!-- Add Variable Modal -->	
		<div id="automad-add-variable-modal" class="modal fade">
			<div class="modal-dialog">
				<div class="modal-content">
					<div class="modal-header">
						<button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
						<h3 class="modal-title"><?php echo $this->tb['special_pages_btn_add']; ?></h3>
						<div class="alert alert-info">
							<?php echo $this->tb['special_pages_add_info']; ?> 
						</div>
					</div>
					<div class="modal-body">
						<div class="form-group">
							<label for="automad-add-variable-name"><?php echo $this->tb['special_pages_var_name']; ?></label> 
							<input type="text" class="form-control" id="automad-add-variable-name" onkeypress="return event.keyCode != 13;" />
						</div>	
					</div>
					<div class="modal-footer">
						<div class="btn-group btn-group-justified">
							<div class="btn-group">
								<button type="button" class="btn btn-default" data-dismiss="modal">
									<span class="glyphicon glyphicon-remove"></span> <?php echo $this->tb['btn_close']; ?>
								</button>
							</div>
							<div class="btn-group">
								<button type="button" class="btn btn-primary" id="automad-add-variable-button" data-automad-error-exists="<?php echo $this->tb['error_var_exists']; ?>" data-automad-error-name="<?php echo $this->tb['error_var_name']; ?>">
									<span class="glyphicon glyphicon-plus"></span> <?php echo $this->tb['btn_add']; ?> 
								</button>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>		
	
	<?php	


	// Save buffer to JSON array.
	$output['html'] = ob_get_contents();
	ob_end_clean();
	
	
}


echo json_encode($output);


?>